==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/VirtualServiceSpecFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import javax.validation.Valid;
import java.util.Collection;

public interface VirtualServiceSpecFluent<A extends VirtualServiceSpecFluent<A>> extends Fluent<A>{


    public A addToGateways(int index,String item);
    public A setToGateways(int index,String item);
    public A addToGateways(String... items);
    public A addAllToGateways(Collection<String> items);
    public A removeFromGateways(String... items);
    public A removeAllFromGateways(Collection<String> items);
    public List<String> getGateways();
    public String getGateway(int index);
    public String getFirstGateway();
    public String getLastGateway();
    public String getMatchingGateway(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withGateways(List<String> gateways);
    public A withGateways(String... gateways);
    public Boolean hasGateways();
    public A addToHosts(int index,String item);
    public A setToHosts(int index,String item);
    public A addToHosts(String... items);
    public A addAllToHosts(Collection<String> items);
    public A removeFromHosts(String... items);
    public A removeAllFromHosts(Collection<String> items);
    public List<String> getHosts();
    public String getHost(int index);
    public String getFirstHost();
    public String getLastHost();
    public String getMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withHosts(List<String> hosts);
    public A withHosts(String... hosts);
    public Boolean hasHosts();
    public A addToHttp(int index,HTTPRoute item);
    public A setToHttp(int index,HTTPRoute item);
    public A addToHttp(HTTPRoute... items);
    public A addAllToHttp(Collection<HTTPRoute> items);
    public A removeFromHttp(HTTPRoute... items);
    public A removeAllFromHttp(Collection<HTTPRoute> items);
    
/**
 * This method has been deprecated, please use method buildHttp instead.
 * @return The buildable object.
 */
@Deprecated public List<HTTPRoute> getHttp();
    public List<HTTPRoute> buildHttp();
    public HTTPRoute buildHttp(int index);
    public HTTPRoute buildFirstHttp();
    public HTTPRoute buildLastHttp();
    public HTTPRoute buildMatchingHttp(io.fabric8.kubernetes.api.builder.Predicate<HTTPRouteBuilder> predicate);
    public A withHttp(List<HTTPRoute> http);
    public A withHttp(HTTPRoute... http);
    public Boolean hasHttp();
    public VirtualServiceSpecFluent.HttpNested<A> addNewHttp();
    public VirtualServiceSpecFluent.HttpNested<A> addNewHttpLike(HTTPRoute item);
    public VirtualServiceSpecFluent.HttpNested<A> setNewHttpLike(int index,HTTPRoute item);
    public VirtualServiceSpecFluent.HttpNested<A> editHttp(int index);
    public VirtualServiceSpecFluent.HttpNested<A> editFirstHttp();
    public VirtualServiceSpecFluent.HttpNested<A> editLastHttp();
    public VirtualServiceSpecFluent.HttpNested<A> editMatchingHttp(io.fabric8.kubernetes.api.builder.Predicate<HTTPRouteBuilder> predicate);
    public A addToTcp(int index,TCPRoute item);
    public A setToTcp(int index,TCPRoute item);
    public A addToTcp(TCPRoute... items);
    public A addAllToTcp(Collection<TCPRoute> items);
    public A removeFromTcp(TCPRoute... items);
    public A removeAllFromTcp(Collection<TCPRoute> items);
    
/**
 * This method has been deprecated, please use method buildTcp instead.
 * @return The buildable object.
 */
@Deprecated public List<TCPRoute> getTcp();
    public List<TCPRoute> buildTcp();
    public TCPRoute buildTcp(int index);
    public TCPRoute buildFirstTcp();
    public TCPRoute buildLastTcp();
    public TCPRoute buildMatchingTcp(io.fabric8.kubernetes.api.builder.Predicate<TCPRouteBuilder> predicate);
    public A withTcp(List<TCPRoute> tcp);
    public A withTcp(TCPRoute... tcp);
    public Boolean hasTcp();
    public VirtualServiceSpecFluent.TcpNested<A> addNewTcp();
    public VirtualServiceSpecFluent.TcpNested<A> addNewTcpLike(TCPRoute item);
    public VirtualServiceSpecFluent.TcpNested<A> setNewTcpLike(int index,TCPRoute item);
    public VirtualServiceSpecFluent.TcpNested<A> editTcp(int index);
    public VirtualServiceSpecFluent.TcpNested<A> editFirstTcp();
    public VirtualServiceSpecFluent.TcpNested<A> editLastTcp();
    public VirtualServiceSpecFluent.TcpNested<A> editMatchingTcp(io.fabric8.kubernetes.api.builder.Predicate<TCPRouteBuilder> predicate);
    public A addToTls(int index,TLSRoute item);
    public A setToTls(int index,TLSRoute item);
    public A addToTls(TLSRoute... items);
    public A addAllToTls(Collection<TLSRoute> items);
    public A removeFromTls(TLSRoute... items);
    public A removeAllFromTls(Collection<TLSRoute> items);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<TLSRoute> getTls();
    public List<TLSRoute> buildTls();
    public TLSRoute buildTl(int index);
    public TLSRoute buildFirstTl();
    public TLSRoute buildLastTl();
    public TLSRoute buildMatchingTl(io.fabric8.kubernetes.api.builder.Predicate<TLSRouteBuilder> predicate);
    public A withTls(List<TLSRoute> tls);
    public A withTls(TLSRoute... tls);
    public Boolean hasTls();
    public VirtualServiceSpecFluent.TlsNested<A> addNewTl();
    public VirtualServiceSpecFluent.TlsNested<A> addNewTlLike(TLSRoute item);
    public VirtualServiceSpecFluent.TlsNested<A> setNewTlLike(int index,TLSRoute item);
    public VirtualServiceSpecFluent.TlsNested<A> editTl(int index);
    public VirtualServiceSpecFluent.TlsNested<A> editFirstTl();
    public VirtualServiceSpecFluent.TlsNested<A> editLastTl();
    public VirtualServiceSpecFluent.TlsNested<A> editMatchingTl(io.fabric8.kubernetes.api.builder.Predicate<TLSRouteBuilder> predicate);

    public interface HttpNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HTTPRouteFluent<VirtualServiceSpecFluent.HttpNested<N>>{

        
    public N and();    public N endHttp();
}
    public interface TcpNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TCPRouteFluent<VirtualServiceSpecFluent.TcpNested<N>>{

        
    public N and();    public N endTcp();
}
    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSRouteFluent<VirtualServiceSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/VirtualServiceSpecFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface VirtualServiceSpecFluent<A extends VirtualServiceSpecFluent<A>> extends Fluent<A>{


    public A addToExportTo(int index,String item);
    public A setToExportTo(int index,String item);
    public A addToExportTo(String... items);
    public A addAllToExportTo(Collection<String> items);
    public A removeFromExportTo(String... items);
    public A removeAllFromExportTo(Collection<String> items);
    public List<String> getExportTo();
    public String getExportTo(int index);
    public String getFirstExportTo();
    public String getLastExportTo();
    public String getMatchingExportTo(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingExportTo(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withExportTo(List<String> exportTo);
    public A withExportTo(String... exportTo);
    public Boolean hasExportTo();
    public A addNewExportTo(String arg1);
    public A addNewExportTo(StringBuilder arg1);
    public A addNewExportTo(StringBuffer arg1);
    public A addToGateways(int index,String item);
    public A setToGateways(int index,String item);
    public A addToGateways(String... items);
    public A addAllToGateways(Collection<String> items);
    public A removeFromGateways(String... items);
    public A removeAllFromGateways(Collection<String> items);
    public List<String> getGateways();
    public String getGateway(int index);
    public String getFirstGateway();
    public String getLastGateway();
    public String getMatchingGateway(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingGateway(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withGateways(List<String> gateways);
    public A withGateways(String... gateways);
    public Boolean hasGateways();
    public A addNewGateway(String arg1);
    public A addNewGateway(StringBuilder arg1);
    public A addNewGateway(StringBuffer arg1);
    public A addToHosts(int index,String item);
    public A setToHosts(int index,String item);
    public A addToHosts(String... items);
    public A addAllToHosts(Collection<String> items);
    public A removeFromHosts(String... items);
    public A removeAllFromHosts(Collection<String> items);
    public List<String> getHosts();
    public String getHost(int index);
    public String getFirstHost();
    public String getLastHost();
    public String getMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withHosts(List<String> hosts);
    public A withHosts(String... hosts);
    public Boolean hasHosts();
    public A addNewHost(String arg1);
    public A addNewHost(StringBuilder arg1);
    public A addNewHost(StringBuffer arg1);
    public A addToHttp(int index,HTTPRoute item);
    public A setToHttp(int index,HTTPRoute item);
    public A addToHttp(HTTPRoute... items);
    public A addAllToHttp(Collection<HTTPRoute> items);
    public A removeFromHttp(HTTPRoute... items);
    public A removeAllFromHttp(Collection<HTTPRoute> items);
    public A removeMatchingFromHttp(io.fabric8.kubernetes.api.builder.Predicate<HTTPRouteBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildHttp instead.
 * @return The buildable object.
 */
@Deprecated public List<HTTPRoute> getHttp();
    public List<HTTPRoute> buildHttp();
    public HTTPRoute buildHttp(int index);
    public HTTPRoute buildFirstHttp();
    public HTTPRoute buildLastHttp();
    public HTTPRoute buildMatchingHttp(io.fabric8.kubernetes.api.builder.Predicate<HTTPRouteBuilder> predicate);
    public Boolean hasMatchingHttp(io.fabric8.kubernetes.api.builder.Predicate<HTTPRouteBuilder> predicate);
    public A withHttp(List<HTTPRoute> http);
    public A withHttp(HTTPRoute... http);
    public Boolean hasHttp();
    public VirtualServiceSpecFluent.HttpNested<A> addNewHttp();
    public VirtualServiceSpecFluent.HttpNested<A> addNewHttpLike(HTTPRoute item);
    public VirtualServiceSpecFluent.HttpNested<A> setNewHttpLike(int index,HTTPRoute item);
    public VirtualServiceSpecFluent.HttpNested<A> editHttp(int index);
    public VirtualServiceSpecFluent.HttpNested<A> editFirstHttp();
    public VirtualServiceSpecFluent.HttpNested<A> editLastHttp();
    public VirtualServiceSpecFluent.HttpNested<A> editMatchingHttp(io.fabric8.kubernetes.api.builder.Predicate<HTTPRouteBuilder> predicate);
    public A addToTcp(int index,TCPRoute item);
    public A setToTcp(int index,TCPRoute item);
    public A addToTcp(TCPRoute... items);
    public A addAllToTcp(Collection<TCPRoute> items);
    public A removeFromTcp(TCPRoute... items);
    public A removeAllFromTcp(Collection<TCPRoute> items);
    public A removeMatchingFromTcp(io.fabric8.kubernetes.api.builder.Predicate<TCPRouteBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTcp instead.
 * @return The buildable object.
 */
@Deprecated public List<TCPRoute> getTcp();
    public List<TCPRoute> buildTcp();
    public TCPRoute buildTcp(int index);
    public TCPRoute buildFirstTcp();
    public TCPRoute buildLastTcp();
    public TCPRoute buildMatchingTcp(io.fabric8.kubernetes.api.builder.Predicate<TCPRouteBuilder> predicate);
    public Boolean hasMatchingTcp(io.fabric8.kubernetes.api.builder.Predicate<TCPRouteBuilder> predicate);
    public A withTcp(List<TCPRoute> tcp);
    public A withTcp(TCPRoute... tcp);
    public Boolean hasTcp();
    public VirtualServiceSpecFluent.TcpNested<A> addNewTcp();
    public VirtualServiceSpecFluent.TcpNested<A> addNewTcpLike(TCPRoute item);
    public VirtualServiceSpecFluent.TcpNested<A> setNewTcpLike(int index,TCPRoute item);
    public VirtualServiceSpecFluent.TcpNested<A> editTcp(int index);
    public VirtualServiceSpecFluent.TcpNested<A> editFirstTcp();
    public VirtualServiceSpecFluent.TcpNested<A> editLastTcp();
    public VirtualServiceSpecFluent.TcpNested<A> editMatchingTcp(io.fabric8.kubernetes.api.builder.Predicate<TCPRouteBuilder> predicate);
    public A addToTls(int index,TLSRoute item);
    public A setToTls(int index,TLSRoute item);
    public A addToTls(TLSRoute... items);
    public A addAllToTls(Collection<TLSRoute> items);
    public A removeFromTls(TLSRoute... items);
    public A removeAllFromTls(Collection<TLSRoute> items);
    public A removeMatchingFromTls(io.fabric8.kubernetes.api.builder.Predicate<TLSRouteBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<TLSRoute> getTls();
    public List<TLSRoute> buildTls();
    public TLSRoute buildTl(int index);
    public TLSRoute buildFirstTl();
    public TLSRoute buildLastTl();
    public TLSRoute buildMatchingTl(io.fabric8.kubernetes.api.builder.Predicate<TLSRouteBuilder> predicate);
    public Boolean hasMatchingTl(io.fabric8.kubernetes.api.builder.Predicate<TLSRouteBuilder> predicate);
    public A withTls(List<TLSRoute> tls);
    public A withTls(TLSRoute... tls);
    public Boolean hasTls();
    public VirtualServiceSpecFluent.TlsNested<A> addNewTl();
    public VirtualServiceSpecFluent.TlsNested<A> addNewTlLike(TLSRoute item);
    public VirtualServiceSpecFluent.TlsNested<A> setNewTlLike(int index,TLSRoute item);
    public VirtualServiceSpecFluent.TlsNested<A> editTl(int index);
    public VirtualServiceSpecFluent.TlsNested<A> editFirstTl();
    public VirtualServiceSpecFluent.TlsNested<A> editLastTl();
    public VirtualServiceSpecFluent.TlsNested<A> editMatchingTl(io.fabric8.kubernetes.api.builder.Predicate<TLSRouteBuilder> predicate);

    public interface HttpNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HTTPRouteFluent<VirtualServiceSpecFluent.HttpNested<N>>{

        
    public N and();    public N endHttp();
}
    public interface TcpNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TCPRouteFluent<VirtualServiceSpecFluent.TcpNested<N>>{

        
    public N and();    public N endTcp();
}
    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSRouteFluent<VirtualServiceSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}
